.. katsdptelstate documentation master file, created by
   sphinx-quickstart on Mon Jun  3 14:08:13 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to katsdptelstate's documentation!
==========================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   User manual <intro.rst>
   Reference manual <modules.rst>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
